summaryrefslogtreecommitdiffstats
path: root/net
diff options
context:
space:
mode:
authorpkasting <pkasting@chromium.org>2015-02-27 18:53:46 -0800
committerCommit bot <commit-bot@chromium.org>2015-02-28 02:54:19 +0000
commit93ba27f64c6ec7a8ee1f7aa9af11cca964d26eed (patch)
tree02da6e05290b1faf8d369255dcd9218ed63dba9a /net
parenteeb8f30a4ea6e1adcdbafe95ef164b9c4725d7ed (diff)
downloadchromium_src-93ba27f64c6ec7a8ee1f7aa9af11cca964d26eed.zip
chromium_src-93ba27f64c6ec7a8ee1f7aa9af11cca964d26eed.tar.gz
chromium_src-93ba27f64c6ec7a8ee1f7aa9af11cca964d26eed.tar.bz2
Split bug 455884 into separate bugs for each janky piece and remove the
remaining instrumentation of non-janky functions. BUG=455884,462811,462812,462813,462815 TEST=none TBR=mmenke Review URL: https://codereview.chromium.org/964013002 Cr-Commit-Position: refs/heads/master@{#318583}
Diffstat (limited to 'net')
-rw-r--r--net/http/http_stream_factory_impl_job.cc40
-rw-r--r--net/socket/ssl_client_socket_pool.cc34
2 files changed, 8 insertions, 66 deletions
diff --git a/net/http/http_stream_factory_impl_job.cc b/net/http/http_stream_factory_impl_job.cc
index 510d64e..f9f6e39 100644
--- a/net/http/http_stream_factory_impl_job.cc
+++ b/net/http/http_stream_factory_impl_job.cc
@@ -441,10 +441,6 @@ void HttpStreamFactoryImpl::Job::OnIOComplete(int result) {
}
int HttpStreamFactoryImpl::Job::RunLoop(int result) {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 HttpStreamFactoryImpl::Job::RunLoop"));
result = DoLoop(result);
if (result == ERR_IO_PENDING)
@@ -621,10 +617,6 @@ int HttpStreamFactoryImpl::Job::StartInternal() {
}
int HttpStreamFactoryImpl::Job::DoStart() {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 HttpStreamFactoryImpl::Job::DoStart"));
origin_ = HostPortPair::FromURL(request_info_.url);
origin_url_ = stream_factory_->ApplyHostMappingRules(
request_info_.url, &origin_);
@@ -655,10 +647,6 @@ int HttpStreamFactoryImpl::Job::DoStart() {
}
int HttpStreamFactoryImpl::Job::DoResolveProxy() {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 HttpStreamFactoryImpl::Job::DoResolveProxy"));
DCHECK(!pac_request_);
DCHECK(session_);
@@ -675,10 +663,6 @@ int HttpStreamFactoryImpl::Job::DoResolveProxy() {
}
int HttpStreamFactoryImpl::Job::DoResolveProxyComplete(int result) {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 HttpStreamFactoryImpl::Job::DoResolveProxyComplete"));
pac_request_ = NULL;
if (result == OK) {
@@ -752,10 +736,10 @@ int HttpStreamFactoryImpl::Job::DoWaitForJobComplete(int result) {
}
int HttpStreamFactoryImpl::Job::DoInitConnection() {
// TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 HttpStreamFactoryImpl::Job::DoInitConnection"));
+ "462812 HttpStreamFactoryImpl::Job::DoInitConnection"));
DCHECK(!blocking_job_);
DCHECK(!connection_->is_initialized());
DCHECK(proxy_info_.proxy_server().is_valid());
@@ -903,10 +887,6 @@ int HttpStreamFactoryImpl::Job::DoInitConnection() {
}
int HttpStreamFactoryImpl::Job::DoInitConnectionComplete(int result) {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 HttpStreamFactoryImpl::Job::DoInitConnectionComplete"));
if (IsPreconnecting()) {
if (using_quic_)
return result;
@@ -1093,10 +1073,10 @@ int HttpStreamFactoryImpl::Job::SetSpdyHttpStream(
}
int HttpStreamFactoryImpl::Job::DoCreateStream() {
// TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 HttpStreamFactoryImpl::Job::DoCreateStream"));
+ "462811 HttpStreamFactoryImpl::Job::DoCreateStream"));
DCHECK(connection_->socket() || existing_spdy_session_.get() || using_quic_);
next_state_ = STATE_CREATE_STREAM_COMPLETE;
@@ -1190,10 +1170,6 @@ int HttpStreamFactoryImpl::Job::DoCreateStream() {
}
int HttpStreamFactoryImpl::Job::DoCreateStreamComplete(int result) {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 HttpStreamFactoryImpl::Job::DoCreateStreamComplete"));
if (result < 0)
return result;
@@ -1204,10 +1180,6 @@ int HttpStreamFactoryImpl::Job::DoCreateStreamComplete(int result) {
}
int HttpStreamFactoryImpl::Job::DoRestartTunnelAuth() {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 HttpStreamFactoryImpl::Job::DoRestartTunnelAuth"));
next_state_ = STATE_RESTART_TUNNEL_AUTH_COMPLETE;
ProxyClientSocket* proxy_socket =
static_cast<ProxyClientSocket*>(connection_->socket());
@@ -1215,10 +1187,6 @@ int HttpStreamFactoryImpl::Job::DoRestartTunnelAuth() {
}
int HttpStreamFactoryImpl::Job::DoRestartTunnelAuthComplete(int result) {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 HttpStreamFactoryImpl::Job::DoRestartTunnelAuthComplete"));
if (result == ERR_PROXY_AUTH_REQUESTED)
return result;
@@ -752,10 +736,10 @@ int HttpStreamFactoryImpl::Job::DoWaitForJobComplete(int result) {
}
int HttpStreamFactoryImpl::Job::DoInitConnection() {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
+ // TODO(pkasting): Remove ScopedTracker below once crbug.com/462812 is fixed.
tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
@@ -1093,10 +1073,10 @@ int HttpStreamFactoryImpl::Job::SetSpdyHttpStream(
}
int HttpStreamFactoryImpl::Job::DoCreateStream() {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
+ // TODO(pkasting): Remove ScopedTracker below once crbug.com/462811 is fixed.
tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
diff --git a/net/socket/ssl_client_socket_pool.cc b/net/socket/ssl_client_socket_pool.cc
index 827a4de..6643ef4 100644
--- a/net/socket/ssl_client_socket_pool.cc
+++ b/net/socket/ssl_client_socket_pool.cc
@@ -247,9 +247,6 @@ void SSLConnectJob::GetAdditionalErrorState(ClientSocketHandle* handle) {
}
void SSLConnectJob::OnIOComplete(int result) {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION("455884 SSLConnectJob::OnIOComplete"));
int rv = DoLoop(result);
if (rv != ERR_IO_PENDING)
NotifyDelegateOfCompletion(rv); // Deletes |this|.
@@ -308,10 +305,6 @@ int SSLConnectJob::DoLoop(int result) {
}
int SSLConnectJob::DoTransportConnect() {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 SSLConnectJob::DoTransportConnect"));
DCHECK(transport_pool_);
next_state_ = STATE_TRANSPORT_CONNECT_COMPLETE;
@@ -334,9 +327,6 @@ int SSLConnectJob::DoTransportConnectComplete(int result) {
}
int SSLConnectJob::DoSOCKSConnect() {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION("455884 SSLConnectJob::DoSOCKSConnect"));
DCHECK(socks_pool_);
next_state_ = STATE_SOCKS_CONNECT_COMPLETE;
transport_socket_handle_.reset(new ClientSocketHandle());
@@ -358,10 +348,6 @@ int SSLConnectJob::DoSOCKSConnectComplete(int result) {
}
int SSLConnectJob::DoTunnelConnect() {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 SSLConnectJob::DoTunnelConnect"));
DCHECK(http_proxy_pool_);
next_state_ = STATE_TUNNEL_CONNECT_COMPLETE;
@@ -377,10 +363,6 @@ int SSLConnectJob::DoTunnelConnect() {
}
int SSLConnectJob::DoTunnelConnectComplete(int result) {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 SSLConnectJob::DoTunnelConnectComplete"));
// Extract the information needed to prompt for appropriate proxy
// authentication so that when ClientSocketPoolBaseHelper calls
// |GetAdditionalErrorState|, we can easily set the state.
@@ -399,10 +381,10 @@ int SSLConnectJob::DoTunnelConnectComplete(int result) {
}
int SSLConnectJob::DoCreateSSLSocket() {
// TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 SSLConnectJob::DoCreateSSLSocket"));
+ "462815 SSLConnectJob::DoCreateSSLSocket"));
next_state_ = STATE_CHECK_FOR_RESUME;
// Reset the timeout to just the time allowed for the SSL handshake.
@@ -435,10 +417,6 @@ int SSLConnectJob::DoCreateSSLSocket() {
}
int SSLConnectJob::DoCheckForResume() {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 SSLConnectJob::DoCheckForResume"));
next_state_ = STATE_SSL_CONNECT;
if (!messenger_)
@@ -460,9 +438,9 @@ int SSLConnectJob::DoCheckForResume() {
}
int SSLConnectJob::DoSSLConnect() {
// TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION("455884 SSLConnectJob::DoSSLConnect"));
+ FROM_HERE_WITH_EXPLICIT_FUNCTION("462813 SSLConnectJob::DoSSLConnect"));
next_state_ = STATE_SSL_CONNECT_COMPLETE;
connect_timing_.ssl_start = base::TimeTicks::Now();
@@ -471,10 +449,6 @@ int SSLConnectJob::DoSSLConnect() {
}
int SSLConnectJob::DoSSLConnectComplete(int result) {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
- tracked_objects::ScopedTracker tracking_profile(
- FROM_HERE_WITH_EXPLICIT_FUNCTION(
- "455884 SSLConnectJob::DoSSLConnectComplete"));
connect_timing_.ssl_end = base::TimeTicks::Now();
SSLClientSocket::NextProtoStatus status =
@@ -399,10 +381,10 @@ int SSLConnectJob::DoTunnelConnectComplete(int result) {
}
int SSLConnectJob::DoCreateSSLSocket() {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
+ // TODO(pkasting): Remove ScopedTracker below once crbug.com/462815 is fixed.
tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
@@ -460,9 +438,9 @@ int SSLConnectJob::DoCheckForResume() {
}
int SSLConnectJob::DoSSLConnect() {
- // TODO(pkasting): Remove ScopedTracker below once crbug.com/455884 is fixed.
+ // TODO(pkasting): Remove ScopedTracker below once crbug.com/462813 is fixed.
tracked_objects::ScopedTracker tracking_profile(